// Controllore di step motor A4998, Arduino Nano, usando la Libreria AccelStepper.h.
// Motore stepper da: 0.9° x step, 400 steps = 1 giro di 360°, durata 8 secondi.
// Il programma prevede 3 cicli, rispettivamente da 10 + 10 giri, seguito da uno da 5 + 5 giri e da un ultimo
// da 1,5 + 1,5 giri, ciascuno intervallato e terminato da pause, per un totale di 33 giri, in 10 minuti e 15 secondi
// (i giri sono sia in senso orario e sia antiorario).
// Questi tre cicli vengono ripetuti per 4 volte, per un totale di 132 giri in 41 minuti.
// Alla fine di questa ripetizione, il programma prevede una pausa di 19 minuti, che porta il tempo totale
// ad 1 ora. Dopo di che, ricomincia di nuovo il ciclo di 3, ripetuto 4 volte. 
// Ho aggiunto un circuito composto da 3 transistor NPN, 3 resistenze da 200 Ohm, con relative righe 
// di codice, che gestisce tre led di colore diverso (VERDE, BIANCO e ROSSO: Bandiera Italiana!). 
// Quando si fornisce alimentazione, si accendono in sequenza i tre led. Dopo di che, si spengono gli ultimi due e 
// resta acceso il led Verde, che indica il primo ciclo, poi Il Bianco, il secondo ciclo e il Rosso, il terzo ciclo.  
// Infine, dopo 4 ripetizioni, ad inizio del loop di 19 minuti, si accendono in successione i tre led, restano accesi e 
// poi si spengono in successione contraria alla fine del medesimo loop.
// Caricato sulla Giostra il 19 aprile 2020.
//
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include <AccelStepper.h>

#define dirPin 4
#define stepPin 5
#define enablePin 6
#define motorInterfaceType 1

int ledPin1 = 3; // Led Green
int ledPin2 = 10; // Led White
int ledPin3 = 11; // Led Red 

// Creare una nuova instanza della classe AccelStepper:
AccelStepper stepper = AccelStepper(motorInterfaceType, stepPin, dirPin, enablePin);

void setup() {
  Serial.begin(9600);
  stepper.setMaxSpeed(1000);
  digitalWrite(ledPin1, OUTPUT); // Led Green
  digitalWrite(ledPin2, OUTPUT); // Led White
  digitalWrite(ledPin3, OUTPUT); // Led Red
}

void loop() {

  int i = 0;
  // MAX contiene il numero di volte in cui ripete il codice contenuto nel prossimo ciclo "while". 
  
  int MAX = 4;
  while (i < MAX) {
     i++;

  //////////////////////////// PRIMO CICLO /////////////////////////////////////////
  ///////////////////////////////// ////////////////////////////////////////////////
  digitalWrite(ledPin1, LOW);
  digitalWrite(ledPin2, LOW);
  digitalWrite(ledPin3, LOW);
  
  digitalWrite(6,HIGH); // Set Enable high to disable motor.
  delay(1000);
  digitalWrite(ledPin1, HIGH);
  delay(1000);
  digitalWrite(ledPin2, HIGH);
  delay(1000);
  digitalWrite(ledPin3, HIGH);
  delay (8000); // 8 secondi
  digitalWrite(ledPin3, LOW);
  delay(1000);
  digitalWrite(ledPin2, LOW);
  digitalWrite(6,LOW); // Set Enable low to allow motor to run.
  
  
  // Set the current position to 0:
  stepper.setCurrentPosition(0);
  // Fa girare il motore in senso orario per 50 steps al secondo, fino a 4000 step (10 giri):
  while(stepper.currentPosition() != 4000)
  {
    stepper.setSpeed(50);
    stepper.runSpeed();
  }
  digitalWrite(6,HIGH); // Set Enable high to disable motor.
  delay(5000);
  

 // Reset the position to 0:
 digitalWrite(6,LOW); // Set Enable low to allow motor to run.
  stepper.setCurrentPosition(0);
  // Fa girare il motore in senso antiorario per 4000 step (10 giri):
  while(stepper.currentPosition() != -4000) 
  {
    stepper.setSpeed(-50);
    stepper.runSpeed();
  }
  digitalWrite(6,HIGH); // Set Enable high to disable motor.
  delay(20000);
  digitalWrite(ledPin1, LOW);
  
  /////////////////// SECONDO CICLO //////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////
  
  // Reset the position to 0:
  digitalWrite(6,LOW); // Set Enable low to allow motor to run.
  digitalWrite(ledPin2, HIGH);
  
  stepper.setCurrentPosition(0);
  // Fa girare il motore per 2000 step orario (5 giri):
  while(stepper.currentPosition() != 2000)
  {
    stepper.setSpeed(50);
    stepper.runSpeed();
  }

  digitalWrite(6,HIGH); // Set Enable high to disable motor.
  delay(5000);
  
  
  // Reset the position to 0:
  digitalWrite(6,LOW); // Set Enable low to allow motor to run.
  stepper.setCurrentPosition(0);
  // Fa girare il motore per 2000 giri in senso antiorario (5 giri):
  while(stepper.currentPosition() != -2000)
  {
    stepper.setSpeed(-50);
    stepper.runSpeed();
  }

  digitalWrite(6,HIGH); // Set Enable high to disable motor.
  delay(10000);
  digitalWrite(ledPin2, LOW);
  
  ///////////////////////////////// TERZO CICLO /////////////////////////
  ///////////////////////////////////////////////////////////////////////
  
  // Reset the position to 0:
  digitalWrite(6,LOW); // Set Enable low to allow motor to run.
  digitalWrite(ledPin3, HIGH);
  stepper.setCurrentPosition(0);
  // Fa girare il motore per 600 step (un giro e mezzo) in senso orario:
  while(stepper.currentPosition() != 600)
  {
    stepper.setSpeed(50);
    stepper.runSpeed();
  }

  //digitalWrite(6,HIGH); // Set Enable high to disable motor.
  delay(2000);
    
  // Reset the position to 0:
  //digitalWrite(6,LOW); // Set Enable low to allow motor to run.
  stepper.setCurrentPosition(0);
  // Fa girare il motore per 600 step (un giro e mezzo) antiorario:
  while(stepper.currentPosition() != -600)
  {
    stepper.setSpeed(-50);
    stepper.runSpeed();
  }

  digitalWrite(6,HIGH); // Set Enable high to disable motor.
  delay(300000);
  digitalWrite(ledPin3, LOW);
 }

 //////////////////////////////////////////FINE DEI TRE CICLI //////////////////////////////////////////////////
 ////////////////////////////////////////////////// LOOP //////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
  // Il prossimo delay contiene il ritardo di attesa in millisecondi, prima di ricominciare il loop di 3 CICLI 

  // Reset the position to 0:
  digitalWrite(6,LOW); // Set Enable low to allow motor to run.
  
  stepper.setCurrentPosition(0);
  digitalWrite(6,HIGH); // Set Enable high to disable motor.
  delay(1500);
  digitalWrite(ledPin1,HIGH);
  delay(1500);
  digitalWrite(ledPin2,HIGH);
  delay(1500);
  digitalWrite(ledPin3,HIGH); 
  delay(400000); // 1000 = 1 SECONDO; 1.140.000 = 19 MINUTI
  digitalWrite(ledPin3,LOW);
  delay(400000);
  digitalWrite(ledPin2, LOW);
  delay(322000);
  digitalWrite(ledPin1, LOW);
  delay(3000);
  digitalWrite(ledPin1, HIGH);
  delay(3000);
  digitalWrite(ledPin2, HIGH);
  delay(3000);
  digitalWrite(ledPin3, HIGH);
  delay(4000);
}
 
